// DLL_Demo.cpp : Defines the entry point for the console application.
//

#include <conio.h>
#include <malloc.h>
#include <windows.h>
#include <direct.h>

#include "stdafx.h"

extern "C" {
   #include "SpiStorm.h"
}

int _tmain(int argc, _TCHAR* argv[])
{
   int Res = 0;

   char *pDataOut1 = NULL;
   char *pDataIn1  = NULL;
   char *pDataOut2 = NULL;
   char *pDataIn2  = NULL;
   char *pDataOut3 = NULL;
   char *pDataIn3  = NULL;

   //
   // Welcome message
   //
   printf("\nStarting DLL demo...\n\n");

   //
   // Open the SPI Storm library and retrieve handle
   //
   printf("Opening the SPI Storm library and retrieve handle...");
   int SpiHandle = spis_CreateInstance();
   printf("done\n\n");

   //
   // Connect to a SPI Storm device
   //
   char SerNum[256];
   do {
      printf("Enter the device serial number (example: 0401092200D) : ", SerNum);
   } while (gets(SerNum) == NULL || SerNum[0] == 0);
   printf("\nConnecting to SPI Storm device with serial number %s...", SerNum);
   Res = spis_Connect(SerNum, 3300);
   if (Res != 0) { printf("failed!\n"); }
   else { printf("done\n"); }

   ///////////////////////////
   // Load SPI project file //
   ///////////////////////////
   if (Res == 0) {
      char *pPojectFileName = "..\\ExampleFile.ssp";
      printf("\nLoading SPI configuration file \"%s\"...", pPojectFileName);
      Res = spis_LoadPrjFile(pPojectFileName, false, true);
      if (Res != 0) { printf("failed!\n"); }
      else { printf("done\n"); }
   }
      
   //
   // Burst the "Phase4" macro
   //
   if (Res == 0) {
      pDataOut1 = (char *)malloc(1);
      pDataIn1  = (char *)malloc(1);
      pDataOut2 = (char *)malloc(1);
      pDataIn2  = (char *)malloc(1);
      pDataOut3 = (char *)malloc(1);
      pDataIn3  = (char *)malloc(1);

      for (int i=0; i<1; i++) {
         *(pDataOut1+i) = 0x10+i; *(pDataIn1+i) = 0;
         *(pDataOut2+i) = 0x10+i+2; *(pDataIn2+i) = 0;
         *(pDataOut3+i) = 0x10+i+4; *(pDataIn3+i) = 0;
      }

      printf("Initialise the burst sequence...");
      Res = spis_StartSequence();
      if (Res != 0) { printf("failed!\n"); }
      else { printf("done\n"); }

      if (Res == 0) {
         printf("Executing the \"1 byte transfer\" and \"1 byte custom access\" macros burst...");
         Res = spis_ExecMacro("1 byte transfer", pDataOut1, pDataIn1);
         if (Res == 0) { Res = spis_ExecMacro("1 byte custom access", pDataOut2, pDataIn2); }
         if (Res == 0) { Res = spis_ExecMacro("1 byte transfer", pDataOut3, pDataIn3); }
         if (Res != 0) { printf("failed with error code 0x%08X\n", Res); }
         else { printf("done\n"); }
      }

      printf("Terminate the burst sequence...");
      Res = spis_EndOfSequence();
      if (Res != 0) { printf("failed!\n"); }
      else { printf("done\n"); }

      printf("*pDataIn1 = 0x%02X\n", *pDataIn1);
      printf("*pDataIn2 = 0x%02X\n", *pDataIn2);
      printf("*pDataIn2 = 0x%02X\n", *pDataIn3);

      delete pDataOut1;
      delete pDataIn1;
      delete pDataOut2;
      delete pDataIn2;
      delete pDataOut3;
      delete pDataIn3;
   }

   //
   // Close the SPI Storm library
   //
   printf("\nClosing the SPI Storm library...");
   spis_DeleteInstance(SpiHandle);
   printf("done\n");

   //
   // Wait for user input to close the window
   //
   printf("\nPress any key...\n");
   int ch = _getch();

	return Res;
}

